@@ -5,7 +5,7 @@ use strict;
 use warnings;
 
 # Version.
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 1;
 
@@ -27,6 +27,8 @@ Task::PYX - Install the PYX modules.
 
 L<PYX>,
 L<PYX::GraphViz>,
+L<PYX::Hist>,
+L<PYX::Parser>,
 L<PYX::Stack>,
 L<PYX::Utils>.
 
@@ -48,6 +50,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
